#include "qmaemo5homescreenadaptor.h"
#include "swipecounter.h"
#include <QtGui>


int main(int argc, char *argv[])
{

    QApplication::setGraphicsSystem("native");
    QApplication app(argc, argv);
    QApplication::setOrganizationName("Maemo");
    QApplication::setApplicationName("SwipeCounter");

    SwipeCounter s;
    QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&s);
    adaptor->setSettingsAvailable(true);
    QObject::connect(adaptor, SIGNAL(settingsRequested()), &s,SLOT(showSettingsDialog()));
    s.show();
    app.exec();
}

